====================
API - LTE Stress LED
====================

.. module:: lannerpsp.sdk_sled_lte_stress

.. currentmodule:: lannerpsp

Regular Classes
===============

The following classes are intended for general use with the devices they
represent. All classes in this section are concrete (not abstract).

LTEStressLED
------------

.. autoclass:: LTEStressLED
    :members: off, set_strength, test

Supported Platforms
===================

The following platforms have been verified and confirmed to be supported:

* `LEC-7242`_

.. _LEC-7242: https://lannerinc.com/products/intelligent-edge-appliances/embedded-platform/lec-7242
